# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AccessPolicyCondition',
    'AccessPolicyRealm',
    'AccessPolicyRealmLabelPolicy',
    'ProviderAwsCloudwatchScrapeJobCustomNamespace',
    'ProviderAwsCloudwatchScrapeJobCustomNamespaceMetric',
    'ProviderAwsCloudwatchScrapeJobService',
    'ProviderAwsCloudwatchScrapeJobServiceMetric',
    'ProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilter',
    'ProviderAzureCredentialAutoDiscoveryConfiguration',
    'ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration',
    'ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfiguration',
    'ProviderAzureCredentialResourceDiscoveryTagFilter',
    'GetAccessPoliciesAccessPolicyResult',
    'GetPrivateDataSourceConnectNetworksPrivateDataSourceConnectNetworkResult',
    'GetProviderAwsCloudwatchScrapeJobCustomNamespaceResult',
    'GetProviderAwsCloudwatchScrapeJobCustomNamespaceMetricResult',
    'GetProviderAwsCloudwatchScrapeJobServiceResult',
    'GetProviderAwsCloudwatchScrapeJobServiceMetricResult',
    'GetProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceMetricResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceMetricResult',
    'GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResourceDiscoveryTagFilterResult',
    'GetProviderAzureCredentialAutoDiscoveryConfigurationResult',
    'GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationResult',
    'GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfigurationResult',
    'GetProviderAzureCredentialResourceDiscoveryTagFilterResult',
]

@pulumi.output_type
class AccessPolicyCondition(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowedSubnets":
            suggest = "allowed_subnets"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccessPolicyCondition. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccessPolicyCondition.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccessPolicyCondition.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allowed_subnets: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] allowed_subnets: Conditions that apply to the access policy,such as IP Allow lists.
        """
        pulumi.set(__self__, "allowed_subnets", allowed_subnets)

    @property
    @pulumi.getter(name="allowedSubnets")
    def allowed_subnets(self) -> Sequence[builtins.str]:
        """
        Conditions that apply to the access policy,such as IP Allow lists.
        """
        return pulumi.get(self, "allowed_subnets")


@pulumi.output_type
class AccessPolicyRealm(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "labelPolicies":
            suggest = "label_policies"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccessPolicyRealm. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccessPolicyRealm.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccessPolicyRealm.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 identifier: builtins.str,
                 type: builtins.str,
                 label_policies: Optional[Sequence['outputs.AccessPolicyRealmLabelPolicy']] = None):
        """
        :param builtins.str identifier: The identifier of the org or stack. For orgs, this is the slug, for stacks, this is the stack ID.
        :param builtins.str type: Whether a policy applies to a Cloud org or a specific stack. Should be one of `org` or `stack`.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "type", type)
        if label_policies is not None:
            pulumi.set(__self__, "label_policies", label_policies)

    @property
    @pulumi.getter
    def identifier(self) -> builtins.str:
        """
        The identifier of the org or stack. For orgs, this is the slug, for stacks, this is the stack ID.
        """
        return pulumi.get(self, "identifier")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Whether a policy applies to a Cloud org or a specific stack. Should be one of `org` or `stack`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="labelPolicies")
    def label_policies(self) -> Optional[Sequence['outputs.AccessPolicyRealmLabelPolicy']]:
        return pulumi.get(self, "label_policies")


@pulumi.output_type
class AccessPolicyRealmLabelPolicy(dict):
    def __init__(__self__, *,
                 selector: builtins.str):
        """
        :param builtins.str selector: The label selector to match in metrics or logs query. Should be in PromQL or LogQL format.
        """
        pulumi.set(__self__, "selector", selector)

    @property
    @pulumi.getter
    def selector(self) -> builtins.str:
        """
        The label selector to match in metrics or logs query. Should be in PromQL or LogQL format.
        """
        return pulumi.get(self, "selector")


@pulumi.output_type
class ProviderAwsCloudwatchScrapeJobCustomNamespace(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "scrapeIntervalSeconds":
            suggest = "scrape_interval_seconds"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProviderAwsCloudwatchScrapeJobCustomNamespace. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProviderAwsCloudwatchScrapeJobCustomNamespace.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProviderAwsCloudwatchScrapeJobCustomNamespace.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: builtins.str,
                 metrics: Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobCustomNamespaceMetric']] = None,
                 scrape_interval_seconds: Optional[builtins.int] = None):
        """
        :param builtins.str name: The name of the custom namespace to scrape.
        :param Sequence['ProviderAwsCloudwatchScrapeJobCustomNamespaceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the custom namespace. Defaults to `300`.
        """
        pulumi.set(__self__, "name", name)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if scrape_interval_seconds is not None:
            pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the custom namespace to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobCustomNamespaceMetric']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> Optional[builtins.int]:
        """
        The interval in seconds to scrape the custom namespace. Defaults to `300`.
        """
        return pulumi.get(self, "scrape_interval_seconds")


@pulumi.output_type
class ProviderAwsCloudwatchScrapeJobCustomNamespaceMetric(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class ProviderAwsCloudwatchScrapeJobService(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceDiscoveryTagFilters":
            suggest = "resource_discovery_tag_filters"
        elif key == "scrapeIntervalSeconds":
            suggest = "scrape_interval_seconds"
        elif key == "tagsToAddToMetrics":
            suggest = "tags_to_add_to_metrics"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProviderAwsCloudwatchScrapeJobService. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProviderAwsCloudwatchScrapeJobService.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProviderAwsCloudwatchScrapeJobService.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: builtins.str,
                 metrics: Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobServiceMetric']] = None,
                 resource_discovery_tag_filters: Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilter']] = None,
                 scrape_interval_seconds: Optional[builtins.int] = None,
                 tags_to_add_to_metrics: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.str name: The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services.
        :param Sequence['ProviderAwsCloudwatchScrapeJobServiceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Please note that AWS metric names must be supplied, and not their PromQL counterparts. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        :param Sequence['ProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterArgs'] resource_discovery_tag_filters: One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals. Defaults to `300`.
        :param Sequence[builtins.str] tags_to_add_to_metrics: A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        """
        pulumi.set(__self__, "name", name)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if resource_discovery_tag_filters is not None:
            pulumi.set(__self__, "resource_discovery_tag_filters", resource_discovery_tag_filters)
        if scrape_interval_seconds is not None:
            pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        if tags_to_add_to_metrics is not None:
            pulumi.set(__self__, "tags_to_add_to_metrics", tags_to_add_to_metrics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobServiceMetric']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Please note that AWS metric names must be supplied, and not their PromQL counterparts. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> Optional[Sequence['outputs.ProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilter']]:
        """
        One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> Optional[builtins.int]:
        """
        The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals. Defaults to `300`.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter(name="tagsToAddToMetrics")
    def tags_to_add_to_metrics(self) -> Optional[Sequence[builtins.str]]:
        """
        A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        """
        return pulumi.get(self, "tags_to_add_to_metrics")


@pulumi.output_type
class ProviderAwsCloudwatchScrapeJobServiceMetric(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class ProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilter(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: The key of the tag filter.
        :param builtins.str value: The value of the tag filter.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        The key of the tag filter.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        The value of the tag filter.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ProviderAzureCredentialAutoDiscoveryConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceTypeConfigurations":
            suggest = "resource_type_configurations"
        elif key == "subscriptionId":
            suggest = "subscription_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProviderAzureCredentialAutoDiscoveryConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProviderAzureCredentialAutoDiscoveryConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProviderAzureCredentialAutoDiscoveryConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 resource_type_configurations: Sequence['outputs.ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration'],
                 subscription_id: builtins.str):
        """
        :param Sequence['ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationArgs'] resource_type_configurations: The list of resource type configurations.
        :param builtins.str subscription_id: The subscription ID of the Azure account.
        """
        pulumi.set(__self__, "resource_type_configurations", resource_type_configurations)
        pulumi.set(__self__, "subscription_id", subscription_id)

    @property
    @pulumi.getter(name="resourceTypeConfigurations")
    def resource_type_configurations(self) -> Sequence['outputs.ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration']:
        """
        The list of resource type configurations.
        """
        return pulumi.get(self, "resource_type_configurations")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> builtins.str:
        """
        The subscription ID of the Azure account.
        """
        return pulumi.get(self, "subscription_id")


@pulumi.output_type
class ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "metricConfigurations":
            suggest = "metric_configurations"
        elif key == "resourceTypeName":
            suggest = "resource_type_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 metric_configurations: Sequence['outputs.ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfiguration'],
                 resource_type_name: builtins.str):
        pulumi.set(__self__, "metric_configurations", metric_configurations)
        pulumi.set(__self__, "resource_type_name", resource_type_name)

    @property
    @pulumi.getter(name="metricConfigurations")
    def metric_configurations(self) -> Sequence['outputs.ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfiguration']:
        return pulumi.get(self, "metric_configurations")

    @property
    @pulumi.getter(name="resourceTypeName")
    def resource_type_name(self) -> builtins.str:
        return pulumi.get(self, "resource_type_name")


@pulumi.output_type
class ProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfiguration(dict):
    def __init__(__self__, *,
                 aggregations: Sequence[builtins.str],
                 dimensions: Sequence[builtins.str],
                 name: builtins.str):
        pulumi.set(__self__, "aggregations", aggregations)
        pulumi.set(__self__, "dimensions", dimensions)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def aggregations(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "aggregations")

    @property
    @pulumi.getter
    def dimensions(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "dimensions")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")


@pulumi.output_type
class ProviderAzureCredentialResourceDiscoveryTagFilter(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: The key of the tag filter.
        :param builtins.str value: The value of the tag filter.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        The key of the tag filter.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        The value of the tag filter.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAccessPoliciesAccessPolicyResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 name: builtins.str,
                 region: builtins.str,
                 status: builtins.str):
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        return pulumi.get(self, "status")


@pulumi.output_type
class GetPrivateDataSourceConnectNetworksPrivateDataSourceConnectNetworkResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 name: builtins.str,
                 region: builtins.str,
                 status: builtins.str):
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        return pulumi.get(self, "status")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobCustomNamespaceResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 scrape_interval_seconds: builtins.int,
                 metrics: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobCustomNamespaceMetricResult']] = None):
        """
        :param builtins.str name: The name of the custom namespace to scrape.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the custom namespace.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobCustomNamespaceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the custom namespace to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> builtins.int:
        """
        The interval in seconds to scrape the custom namespace.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobCustomNamespaceMetricResult']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobCustomNamespaceMetricResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobServiceResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 scrape_interval_seconds: builtins.int,
                 tags_to_add_to_metrics: Sequence[builtins.str],
                 metrics: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobServiceMetricResult']] = None,
                 resource_discovery_tag_filters: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterResult']] = None):
        """
        :param builtins.str name: The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services, metrics, and their statistics.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals.
        :param Sequence[builtins.str] tags_to_add_to_metrics: A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobServiceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterArgs'] resource_discovery_tag_filters: One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        pulumi.set(__self__, "tags_to_add_to_metrics", tags_to_add_to_metrics)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if resource_discovery_tag_filters is not None:
            pulumi.set(__self__, "resource_discovery_tag_filters", resource_discovery_tag_filters)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services, metrics, and their statistics.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> builtins.int:
        """
        The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter(name="tagsToAddToMetrics")
    def tags_to_add_to_metrics(self) -> Sequence[builtins.str]:
        """
        A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        """
        return pulumi.get(self, "tags_to_add_to_metrics")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobServiceMetricResult']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterResult']]:
        """
        One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobServiceMetricResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobServiceResourceDiscoveryTagFilterResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: The key of the tag filter.
        :param builtins.str value: The value of the tag filter.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        The key of the tag filter.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        The value of the tag filter.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobResult(dict):
    def __init__(__self__, *,
                 aws_account_resource_id: builtins.str,
                 disabled_reason: builtins.str,
                 enabled: builtins.bool,
                 export_tags: builtins.bool,
                 id: builtins.str,
                 name: builtins.str,
                 regions: Sequence[builtins.str],
                 regions_subset_override_used: builtins.bool,
                 role_arn: builtins.str,
                 stack_id: builtins.str,
                 static_labels: Mapping[str, builtins.str],
                 custom_namespaces: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceResult']] = None,
                 services: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResult']] = None):
        """
        :param builtins.str aws_account_resource_id: The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this AWS CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        :param builtins.str disabled_reason: When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        :param builtins.bool enabled: Whether the AWS CloudWatch Scrape Job is enabled or not.
        :param builtins.bool export_tags: When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`.
        :param Sequence[builtins.str] regions: The set of AWS region names that this AWS CloudWatch Scrape Job is configured to scrape.
        :param builtins.bool regions_subset_override_used: When true, the `regions` attribute will be the set of regions configured in the override. When false, the `regions` attribute will be the set of regions belonging to the AWS Account resource that is associated with this AWS CloudWatch Scrape Job.
        :param builtins.str role_arn: The AWS ARN of the IAM role associated with the AWS Account resource that is being used by this AWS CloudWatch Scrape Job.
        :param Mapping[str, builtins.str] static_labels: A set of static labels to add to all metrics exported by this scrape job.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceArgs'] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceArgs'] services: One or more configuration blocks to dictate what this AWS CloudWatch Scrape Job should scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        pulumi.set(__self__, "aws_account_resource_id", aws_account_resource_id)
        pulumi.set(__self__, "disabled_reason", disabled_reason)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "export_tags", export_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "regions", regions)
        pulumi.set(__self__, "regions_subset_override_used", regions_subset_override_used)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "stack_id", stack_id)
        pulumi.set(__self__, "static_labels", static_labels)
        if custom_namespaces is not None:
            pulumi.set(__self__, "custom_namespaces", custom_namespaces)
        if services is not None:
            pulumi.set(__self__, "services", services)

    @property
    @pulumi.getter(name="awsAccountResourceId")
    def aws_account_resource_id(self) -> builtins.str:
        """
        The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this AWS CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        """
        return pulumi.get(self, "aws_account_resource_id")

    @property
    @pulumi.getter(name="disabledReason")
    def disabled_reason(self) -> builtins.str:
        """
        When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        """
        return pulumi.get(self, "disabled_reason")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        Whether the AWS CloudWatch Scrape Job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="exportTags")
    def export_tags(self) -> builtins.bool:
        """
        When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`.
        """
        return pulumi.get(self, "export_tags")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[builtins.str]:
        """
        The set of AWS region names that this AWS CloudWatch Scrape Job is configured to scrape.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="regionsSubsetOverrideUsed")
    def regions_subset_override_used(self) -> builtins.bool:
        """
        When true, the `regions` attribute will be the set of regions configured in the override. When false, the `regions` attribute will be the set of regions belonging to the AWS Account resource that is associated with this AWS CloudWatch Scrape Job.
        """
        return pulumi.get(self, "regions_subset_override_used")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> builtins.str:
        """
        The AWS ARN of the IAM role associated with the AWS Account resource that is being used by this AWS CloudWatch Scrape Job.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> builtins.str:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="staticLabels")
    def static_labels(self) -> Mapping[str, builtins.str]:
        """
        A set of static labels to add to all metrics exported by this scrape job.
        """
        return pulumi.get(self, "static_labels")

    @property
    @pulumi.getter(name="customNamespaces")
    def custom_namespaces(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceResult']]:
        """
        Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "custom_namespaces")

    @property
    @pulumi.getter
    def services(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResult']]:
        """
        One or more configuration blocks to dictate what this AWS CloudWatch Scrape Job should scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "services")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 scrape_interval_seconds: builtins.int,
                 metrics: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceMetricResult']] = None):
        """
        :param builtins.str name: The name of the custom namespace to scrape.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the custom namespace.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the custom namespace to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> builtins.int:
        """
        The interval in seconds to scrape the custom namespace.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceMetricResult']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobCustomNamespaceMetricResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 scrape_interval_seconds: builtins.int,
                 tags_to_add_to_metrics: Sequence[builtins.str],
                 metrics: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceMetricResult']] = None,
                 resource_discovery_tag_filters: Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResourceDiscoveryTagFilterResult']] = None):
        """
        :param builtins.str name: The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services, metrics, and their statistics.
        :param builtins.int scrape_interval_seconds: The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals.
        :param Sequence[builtins.str] tags_to_add_to_metrics: A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceMetricArgs'] metrics: One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        :param Sequence['GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResourceDiscoveryTagFilterArgs'] resource_discovery_tag_filters: One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "scrape_interval_seconds", scrape_interval_seconds)
        pulumi.set(__self__, "tags_to_add_to_metrics", tags_to_add_to_metrics)
        if metrics is not None:
            pulumi.set(__self__, "metrics", metrics)
        if resource_discovery_tag_filters is not None:
            pulumi.set(__self__, "resource_discovery_tag_filters", resource_discovery_tag_filters)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the service to scrape. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported services, metrics, and their statistics.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="scrapeIntervalSeconds")
    def scrape_interval_seconds(self) -> builtins.int:
        """
        The interval in seconds to scrape the service. See https://grafana.com/docs/grafana-cloud/monitor-infrastructure/monitor-cloud-provider/aws/cloudwatch-metrics/services/ for supported scrape intervals.
        """
        return pulumi.get(self, "scrape_interval_seconds")

    @property
    @pulumi.getter(name="tagsToAddToMetrics")
    def tags_to_add_to_metrics(self) -> Sequence[builtins.str]:
        """
        A set of tags to add to all metrics exported by this scrape job, for use in PromQL queries.
        """
        return pulumi.get(self, "tags_to_add_to_metrics")

    @property
    @pulumi.getter
    def metrics(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceMetricResult']]:
        """
        One or more configuration blocks to configure metrics and their statistics to scrape. Each block must represent a distinct metric name. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "metrics")

    @property
    @pulumi.getter(name="resourceDiscoveryTagFilters")
    def resource_discovery_tag_filters(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResourceDiscoveryTagFilterResult']]:
        """
        One or more configuration blocks to configure tag filters applied to discovery of resource entities in the associated AWS account. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "resource_discovery_tag_filters")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceMetricResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 statistics: Sequence[builtins.str]):
        """
        :param builtins.str name: The name of the metric to scrape.
        :param Sequence[builtins.str] statistics: A set of statistics to scrape.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "statistics", statistics)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the metric to scrape.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence[builtins.str]:
        """
        A set of statistics to scrape.
        """
        return pulumi.get(self, "statistics")


@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobsScrapeJobServiceResourceDiscoveryTagFilterResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: The key of the tag filter.
        :param builtins.str value: The value of the tag filter.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        The key of the tag filter.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        The value of the tag filter.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetProviderAzureCredentialAutoDiscoveryConfigurationResult(dict):
    def __init__(__self__, *,
                 resource_type_configurations: Sequence['outputs.GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationResult'],
                 subscription_id: builtins.str):
        """
        :param Sequence['GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationArgs'] resource_type_configurations: The list of resource type configurations.
        :param builtins.str subscription_id: The subscription ID of the Azure account.
        """
        pulumi.set(__self__, "resource_type_configurations", resource_type_configurations)
        pulumi.set(__self__, "subscription_id", subscription_id)

    @property
    @pulumi.getter(name="resourceTypeConfigurations")
    def resource_type_configurations(self) -> Sequence['outputs.GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationResult']:
        """
        The list of resource type configurations.
        """
        return pulumi.get(self, "resource_type_configurations")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> builtins.str:
        """
        The subscription ID of the Azure account.
        """
        return pulumi.get(self, "subscription_id")


@pulumi.output_type
class GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationResult(dict):
    def __init__(__self__, *,
                 metric_configurations: Sequence['outputs.GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfigurationResult'],
                 resource_type_name: builtins.str):
        pulumi.set(__self__, "metric_configurations", metric_configurations)
        pulumi.set(__self__, "resource_type_name", resource_type_name)

    @property
    @pulumi.getter(name="metricConfigurations")
    def metric_configurations(self) -> Sequence['outputs.GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfigurationResult']:
        return pulumi.get(self, "metric_configurations")

    @property
    @pulumi.getter(name="resourceTypeName")
    def resource_type_name(self) -> builtins.str:
        return pulumi.get(self, "resource_type_name")


@pulumi.output_type
class GetProviderAzureCredentialAutoDiscoveryConfigurationResourceTypeConfigurationMetricConfigurationResult(dict):
    def __init__(__self__, *,
                 aggregations: Sequence[builtins.str],
                 dimensions: Sequence[builtins.str],
                 name: builtins.str):
        pulumi.set(__self__, "aggregations", aggregations)
        pulumi.set(__self__, "dimensions", dimensions)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def aggregations(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "aggregations")

    @property
    @pulumi.getter
    def dimensions(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "dimensions")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")


@pulumi.output_type
class GetProviderAzureCredentialResourceDiscoveryTagFilterResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: The key of the tag filter.
        :param builtins.str value: The value of the tag filter.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        The key of the tag filter.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        The value of the tag filter.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstallationArgs', 'Installation']

@pulumi.input_type
class InstallationArgs:
    def __init__(__self__, *,
                 cloud_access_policy_token: pulumi.Input[builtins.str],
                 grafana_sa_token: pulumi.Input[builtins.str],
                 grafana_user: pulumi.Input[builtins.str],
                 stack_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a Installation resource.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        :param pulumi.Input[builtins.str] grafana_sa_token: The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        :param pulumi.Input[builtins.str] grafana_user: The user to use for the installation.
        :param pulumi.Input[builtins.str] stack_id: The identifier of the stack to install k6 on.
        """
        pulumi.set(__self__, "cloud_access_policy_token", cloud_access_policy_token)
        pulumi.set(__self__, "grafana_sa_token", grafana_sa_token)
        pulumi.set(__self__, "grafana_user", grafana_user)
        pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter(name="cloudAccessPolicyToken")
    def cloud_access_policy_token(self) -> pulumi.Input[builtins.str]:
        """
        The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        """
        return pulumi.get(self, "cloud_access_policy_token")

    @cloud_access_policy_token.setter
    def cloud_access_policy_token(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cloud_access_policy_token", value)

    @property
    @pulumi.getter(name="grafanaSaToken")
    def grafana_sa_token(self) -> pulumi.Input[builtins.str]:
        """
        The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        """
        return pulumi.get(self, "grafana_sa_token")

    @grafana_sa_token.setter
    def grafana_sa_token(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "grafana_sa_token", value)

    @property
    @pulumi.getter(name="grafanaUser")
    def grafana_user(self) -> pulumi.Input[builtins.str]:
        """
        The user to use for the installation.
        """
        return pulumi.get(self, "grafana_user")

    @grafana_user.setter
    def grafana_user(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "grafana_user", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Input[builtins.str]:
        """
        The identifier of the stack to install k6 on.
        """
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stack_id", value)


@pulumi.input_type
class _InstallationState:
    def __init__(__self__, *,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_sa_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_user: Optional[pulumi.Input[builtins.str]] = None,
                 k6_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 k6_organization: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Installation resources.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        :param pulumi.Input[builtins.str] grafana_sa_token: The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        :param pulumi.Input[builtins.str] grafana_user: The user to use for the installation.
        :param pulumi.Input[builtins.str] k6_access_token: Generated token to access the k6 API.
        :param pulumi.Input[builtins.str] k6_organization: The identifier of the k6 organization.
        :param pulumi.Input[builtins.str] stack_id: The identifier of the stack to install k6 on.
        """
        if cloud_access_policy_token is not None:
            pulumi.set(__self__, "cloud_access_policy_token", cloud_access_policy_token)
        if grafana_sa_token is not None:
            pulumi.set(__self__, "grafana_sa_token", grafana_sa_token)
        if grafana_user is not None:
            pulumi.set(__self__, "grafana_user", grafana_user)
        if k6_access_token is not None:
            pulumi.set(__self__, "k6_access_token", k6_access_token)
        if k6_organization is not None:
            pulumi.set(__self__, "k6_organization", k6_organization)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter(name="cloudAccessPolicyToken")
    def cloud_access_policy_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        """
        return pulumi.get(self, "cloud_access_policy_token")

    @cloud_access_policy_token.setter
    def cloud_access_policy_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cloud_access_policy_token", value)

    @property
    @pulumi.getter(name="grafanaSaToken")
    def grafana_sa_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        """
        return pulumi.get(self, "grafana_sa_token")

    @grafana_sa_token.setter
    def grafana_sa_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grafana_sa_token", value)

    @property
    @pulumi.getter(name="grafanaUser")
    def grafana_user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The user to use for the installation.
        """
        return pulumi.get(self, "grafana_user")

    @grafana_user.setter
    def grafana_user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grafana_user", value)

    @property
    @pulumi.getter(name="k6AccessToken")
    def k6_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Generated token to access the k6 API.
        """
        return pulumi.get(self, "k6_access_token")

    @k6_access_token.setter
    def k6_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "k6_access_token", value)

    @property
    @pulumi.getter(name="k6Organization")
    def k6_organization(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identifier of the k6 organization.
        """
        return pulumi.get(self, "k6_organization")

    @k6_organization.setter
    def k6_organization(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "k6_organization", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identifier of the stack to install k6 on.
        """
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stack_id", value)


@pulumi.type_token("grafana:k6/installation:Installation")
class Installation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_sa_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_user: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Sets up the k6 App on a Grafana Cloud instance and generates a token.
        Once a Grafana Cloud stack is created, a user can either use this resource or go into the UI to install k6.
        This resource cannot be imported but it can be used on an existing k6 App installation without issues.

        **Note that this resource must be used on a provider configured with Grafana Cloud credentials.**

        * [Official documentation](https://grafana.com/docs/grafana-cloud/testing/k6/)

        Required access policy scopes:

        * stacks:read
        * stacks:write
        * subscriptions:read
        * orgs:read

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        config = pulumi.Config()
        # Cloud Access Policy token for Grafana Cloud with the following scopes: stacks:read|write|delete, stack-service-accounts:write
        cloud_access_policy_token = config.require_object("cloudAccessPolicyToken")
        stack_slug = config.require_object("stackSlug")
        cloud_region = config.get("cloudRegion")
        if cloud_region is None:
            cloud_region = "us"
        k6_stack = grafana.cloud.Stack("k6_stack",
            name=stack_slug,
            slug=stack_slug,
            region_slug=cloud_region)
        # Step 2: Create a Service Account and a token to install the k6 App
        k6_sa = grafana.cloud.StackServiceAccount("k6_sa",
            stack_slug=stack_slug,
            name=f"{stack_slug}-k6-app",
            role="Admin",
            is_disabled=False)
        k6_sa_token = grafana.cloud.StackServiceAccountToken("k6_sa_token",
            stack_slug=stack_slug,
            name=f"{stack_slug}-k6-app-token",
            service_account_id=k6_sa.id)
        # Step 3: Install the k6 App on the stack
        k6_installation = grafana.k6.Installation("k6_installation",
            cloud_access_policy_token=cloud_access_policy_token,
            stack_id=k6_stack.id,
            grafana_sa_token=k6_sa_token.key,
            grafana_user="admin")
        my_k6_project = grafana.k6.Project("my_k6_project", name="k6 Project created with TF")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        :param pulumi.Input[builtins.str] grafana_sa_token: The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        :param pulumi.Input[builtins.str] grafana_user: The user to use for the installation.
        :param pulumi.Input[builtins.str] stack_id: The identifier of the stack to install k6 on.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstallationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Sets up the k6 App on a Grafana Cloud instance and generates a token.
        Once a Grafana Cloud stack is created, a user can either use this resource or go into the UI to install k6.
        This resource cannot be imported but it can be used on an existing k6 App installation without issues.

        **Note that this resource must be used on a provider configured with Grafana Cloud credentials.**

        * [Official documentation](https://grafana.com/docs/grafana-cloud/testing/k6/)

        Required access policy scopes:

        * stacks:read
        * stacks:write
        * subscriptions:read
        * orgs:read

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        config = pulumi.Config()
        # Cloud Access Policy token for Grafana Cloud with the following scopes: stacks:read|write|delete, stack-service-accounts:write
        cloud_access_policy_token = config.require_object("cloudAccessPolicyToken")
        stack_slug = config.require_object("stackSlug")
        cloud_region = config.get("cloudRegion")
        if cloud_region is None:
            cloud_region = "us"
        k6_stack = grafana.cloud.Stack("k6_stack",
            name=stack_slug,
            slug=stack_slug,
            region_slug=cloud_region)
        # Step 2: Create a Service Account and a token to install the k6 App
        k6_sa = grafana.cloud.StackServiceAccount("k6_sa",
            stack_slug=stack_slug,
            name=f"{stack_slug}-k6-app",
            role="Admin",
            is_disabled=False)
        k6_sa_token = grafana.cloud.StackServiceAccountToken("k6_sa_token",
            stack_slug=stack_slug,
            name=f"{stack_slug}-k6-app-token",
            service_account_id=k6_sa.id)
        # Step 3: Install the k6 App on the stack
        k6_installation = grafana.k6.Installation("k6_installation",
            cloud_access_policy_token=cloud_access_policy_token,
            stack_id=k6_stack.id,
            grafana_sa_token=k6_sa_token.key,
            grafana_user="admin")
        my_k6_project = grafana.k6.Project("my_k6_project", name="k6 Project created with TF")
        ```

        :param str resource_name: The name of the resource.
        :param InstallationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstallationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_sa_token: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_user: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstallationArgs.__new__(InstallationArgs)

            if cloud_access_policy_token is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_access_policy_token'")
            __props__.__dict__["cloud_access_policy_token"] = None if cloud_access_policy_token is None else pulumi.Output.secret(cloud_access_policy_token)
            if grafana_sa_token is None and not opts.urn:
                raise TypeError("Missing required property 'grafana_sa_token'")
            __props__.__dict__["grafana_sa_token"] = None if grafana_sa_token is None else pulumi.Output.secret(grafana_sa_token)
            if grafana_user is None and not opts.urn:
                raise TypeError("Missing required property 'grafana_user'")
            __props__.__dict__["grafana_user"] = grafana_user
            if stack_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_id'")
            __props__.__dict__["stack_id"] = stack_id
            __props__.__dict__["k6_access_token"] = None
            __props__.__dict__["k6_organization"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["cloudAccessPolicyToken", "grafanaSaToken", "k6AccessToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Installation, __self__).__init__(
            'grafana:k6/installation:Installation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
            grafana_sa_token: Optional[pulumi.Input[builtins.str]] = None,
            grafana_user: Optional[pulumi.Input[builtins.str]] = None,
            k6_access_token: Optional[pulumi.Input[builtins.str]] = None,
            k6_organization: Optional[pulumi.Input[builtins.str]] = None,
            stack_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Installation':
        """
        Get an existing Installation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        :param pulumi.Input[builtins.str] grafana_sa_token: The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        :param pulumi.Input[builtins.str] grafana_user: The user to use for the installation.
        :param pulumi.Input[builtins.str] k6_access_token: Generated token to access the k6 API.
        :param pulumi.Input[builtins.str] k6_organization: The identifier of the k6 organization.
        :param pulumi.Input[builtins.str] stack_id: The identifier of the stack to install k6 on.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstallationState.__new__(_InstallationState)

        __props__.__dict__["cloud_access_policy_token"] = cloud_access_policy_token
        __props__.__dict__["grafana_sa_token"] = grafana_sa_token
        __props__.__dict__["grafana_user"] = grafana_user
        __props__.__dict__["k6_access_token"] = k6_access_token
        __props__.__dict__["k6_organization"] = k6_organization
        __props__.__dict__["stack_id"] = stack_id
        return Installation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cloudAccessPolicyToken")
    def cloud_access_policy_token(self) -> pulumi.Output[builtins.str]:
        """
        The [Grafana Cloud access policy](https://grafana.com/docs/grafana-cloud/account-management/authentication-and-permissions/access-policies/).
        """
        return pulumi.get(self, "cloud_access_policy_token")

    @property
    @pulumi.getter(name="grafanaSaToken")
    def grafana_sa_token(self) -> pulumi.Output[builtins.str]:
        """
        The [service account](https://grafana.com/docs/grafana/latest/administration/service-accounts/) token.
        """
        return pulumi.get(self, "grafana_sa_token")

    @property
    @pulumi.getter(name="grafanaUser")
    def grafana_user(self) -> pulumi.Output[builtins.str]:
        """
        The user to use for the installation.
        """
        return pulumi.get(self, "grafana_user")

    @property
    @pulumi.getter(name="k6AccessToken")
    def k6_access_token(self) -> pulumi.Output[builtins.str]:
        """
        Generated token to access the k6 API.
        """
        return pulumi.get(self, "k6_access_token")

    @property
    @pulumi.getter(name="k6Organization")
    def k6_organization(self) -> pulumi.Output[builtins.str]:
        """
        The identifier of the k6 organization.
        """
        return pulumi.get(self, "k6_organization")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[builtins.str]:
        """
        The identifier of the stack to install k6 on.
        """
        return pulumi.get(self, "stack_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DashboardPublicArgs', 'DashboardPublic']

@pulumi.input_type
class DashboardPublicArgs:
    def __init__(__self__, *,
                 dashboard_uid: pulumi.Input[builtins.str],
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 annotations_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 is_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 share: Optional[pulumi.Input[builtins.str]] = None,
                 time_selection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DashboardPublic resource.
        :param pulumi.Input[builtins.str] dashboard_uid: The unique identifier of the original dashboard.
        :param pulumi.Input[builtins.str] access_token: A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        :param pulumi.Input[builtins.bool] annotations_enabled: Set to `true` to show annotations. The default value is `false`.
        :param pulumi.Input[builtins.bool] is_enabled: Set to `true` to enable the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] share: Set the share mode. The default value is `public`.
        :param pulumi.Input[builtins.bool] time_selection_enabled: Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        pulumi.set(__self__, "dashboard_uid", dashboard_uid)
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if annotations_enabled is not None:
            pulumi.set(__self__, "annotations_enabled", annotations_enabled)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if share is not None:
            pulumi.set(__self__, "share", share)
        if time_selection_enabled is not None:
            pulumi.set(__self__, "time_selection_enabled", time_selection_enabled)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> pulumi.Input[builtins.str]:
        """
        The unique identifier of the original dashboard.
        """
        return pulumi.get(self, "dashboard_uid")

    @dashboard_uid.setter
    def dashboard_uid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "dashboard_uid", value)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter(name="annotationsEnabled")
    def annotations_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to show annotations. The default value is `false`.
        """
        return pulumi.get(self, "annotations_enabled")

    @annotations_enabled.setter
    def annotations_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "annotations_enabled", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to enable the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def share(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the share mode. The default value is `public`.
        """
        return pulumi.get(self, "share")

    @share.setter
    def share(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "share", value)

    @property
    @pulumi.getter(name="timeSelectionEnabled")
    def time_selection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "time_selection_enabled")

    @time_selection_enabled.setter
    def time_selection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "time_selection_enabled", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uid", value)


@pulumi.input_type
class _DashboardPublicState:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 annotations_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dashboard_uid: Optional[pulumi.Input[builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 share: Optional[pulumi.Input[builtins.str]] = None,
                 time_selection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DashboardPublic resources.
        :param pulumi.Input[builtins.str] access_token: A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        :param pulumi.Input[builtins.bool] annotations_enabled: Set to `true` to show annotations. The default value is `false`.
        :param pulumi.Input[builtins.str] dashboard_uid: The unique identifier of the original dashboard.
        :param pulumi.Input[builtins.bool] is_enabled: Set to `true` to enable the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] share: Set the share mode. The default value is `public`.
        :param pulumi.Input[builtins.bool] time_selection_enabled: Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if annotations_enabled is not None:
            pulumi.set(__self__, "annotations_enabled", annotations_enabled)
        if dashboard_uid is not None:
            pulumi.set(__self__, "dashboard_uid", dashboard_uid)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if share is not None:
            pulumi.set(__self__, "share", share)
        if time_selection_enabled is not None:
            pulumi.set(__self__, "time_selection_enabled", time_selection_enabled)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_token", value)

    @property
    @pulumi.getter(name="annotationsEnabled")
    def annotations_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to show annotations. The default value is `false`.
        """
        return pulumi.get(self, "annotations_enabled")

    @annotations_enabled.setter
    def annotations_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "annotations_enabled", value)

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique identifier of the original dashboard.
        """
        return pulumi.get(self, "dashboard_uid")

    @dashboard_uid.setter
    def dashboard_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dashboard_uid", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to enable the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def share(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the share mode. The default value is `public`.
        """
        return pulumi.get(self, "share")

    @share.setter
    def share(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "share", value)

    @property
    @pulumi.getter(name="timeSelectionEnabled")
    def time_selection_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "time_selection_enabled")

    @time_selection_enabled.setter
    def time_selection_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "time_selection_enabled", value)

    @property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uid", value)


warnings.warn("""grafana.index/dashboardpublic.DashboardPublic has been deprecated in favor of grafana.oss/dashboardpublic.DashboardPublic""", DeprecationWarning)


@pulumi.type_token("grafana:index/dashboardPublic:DashboardPublic")
class DashboardPublic(pulumi.CustomResource):
    warnings.warn("""grafana.index/dashboardpublic.DashboardPublic has been deprecated in favor of grafana.oss/dashboardpublic.DashboardPublic""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 annotations_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dashboard_uid: Optional[pulumi.Input[builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 share: Optional[pulumi.Input[builtins.str]] = None,
                 time_selection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages Grafana public dashboards.

        **Note:** This resource is available only with Grafana 10.2+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/share-dashboards-panels/shared-dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/next/developers/http_api/dashboard_public/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        # Optional (On-premise, not supported in Grafana Cloud): Create an organization
        my_org = grafana.oss.Organization("my_org", name="test 1")
        # Create resources (optional: within the organization)
        my_folder = grafana.oss.Folder("my_folder",
            org_id=my_org.org_id,
            title="test Folder")
        test_dash = grafana.oss.Dashboard("test_dash",
            org_id=my_org.org_id,
            folder=my_folder.id,
            config_json=json.dumps({
                "title": "My Terraform Dashboard",
                "uid": "my-dashboard-uid",
            }))
        my_public_dashboard = grafana.oss.DashboardPublic("my_public_dashboard",
            org_id=my_org.org_id,
            dashboard_uid=test_dash.uid,
            uid="my-custom-public-uid",
            access_token="e99e4275da6f410d83760eefa934d8d2",
            time_selection_enabled=True,
            is_enabled=True,
            annotations_enabled=True,
            share="public")
        # Optional (On-premise, not supported in Grafana Cloud): Create an organization
        my_org2 = grafana.oss.Organization("my_org2", name="test 2")
        test_dash2 = grafana.oss.Dashboard("test_dash2",
            org_id=my_org2.org_id,
            config_json=json.dumps({
                "title": "My Terraform Dashboard2",
                "uid": "my-dashboard-uid2",
            }))
        my_public_dashboard2 = grafana.oss.DashboardPublic("my_public_dashboard2",
            org_id=my_org2.org_id,
            dashboard_uid=test_dash2.uid,
            share="public")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dashboardPublic:DashboardPublic name "{{ dashboardUID }}:{{ publicDashboardUID }}"
        ```

        ```sh
        $ pulumi import grafana:index/dashboardPublic:DashboardPublic name "{{ orgID }}:{{ dashboardUID }}:{{ publicDashboardUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_token: A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        :param pulumi.Input[builtins.bool] annotations_enabled: Set to `true` to show annotations. The default value is `false`.
        :param pulumi.Input[builtins.str] dashboard_uid: The unique identifier of the original dashboard.
        :param pulumi.Input[builtins.bool] is_enabled: Set to `true` to enable the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] share: Set the share mode. The default value is `public`.
        :param pulumi.Input[builtins.bool] time_selection_enabled: Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardPublicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana public dashboards.

        **Note:** This resource is available only with Grafana 10.2+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/share-dashboards-panels/shared-dashboards/)
        * [HTTP API](https://grafana.com/docs/grafana/next/developers/http_api/dashboard_public/)

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        # Optional (On-premise, not supported in Grafana Cloud): Create an organization
        my_org = grafana.oss.Organization("my_org", name="test 1")
        # Create resources (optional: within the organization)
        my_folder = grafana.oss.Folder("my_folder",
            org_id=my_org.org_id,
            title="test Folder")
        test_dash = grafana.oss.Dashboard("test_dash",
            org_id=my_org.org_id,
            folder=my_folder.id,
            config_json=json.dumps({
                "title": "My Terraform Dashboard",
                "uid": "my-dashboard-uid",
            }))
        my_public_dashboard = grafana.oss.DashboardPublic("my_public_dashboard",
            org_id=my_org.org_id,
            dashboard_uid=test_dash.uid,
            uid="my-custom-public-uid",
            access_token="e99e4275da6f410d83760eefa934d8d2",
            time_selection_enabled=True,
            is_enabled=True,
            annotations_enabled=True,
            share="public")
        # Optional (On-premise, not supported in Grafana Cloud): Create an organization
        my_org2 = grafana.oss.Organization("my_org2", name="test 2")
        test_dash2 = grafana.oss.Dashboard("test_dash2",
            org_id=my_org2.org_id,
            config_json=json.dumps({
                "title": "My Terraform Dashboard2",
                "uid": "my-dashboard-uid2",
            }))
        my_public_dashboard2 = grafana.oss.DashboardPublic("my_public_dashboard2",
            org_id=my_org2.org_id,
            dashboard_uid=test_dash2.uid,
            share="public")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/dashboardPublic:DashboardPublic name "{{ dashboardUID }}:{{ publicDashboardUID }}"
        ```

        ```sh
        $ pulumi import grafana:index/dashboardPublic:DashboardPublic name "{{ orgID }}:{{ dashboardUID }}:{{ publicDashboardUID }}"
        ```

        :param str resource_name: The name of the resource.
        :param DashboardPublicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardPublicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[builtins.str]] = None,
                 annotations_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dashboard_uid: Optional[pulumi.Input[builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 share: Optional[pulumi.Input[builtins.str]] = None,
                 time_selection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 uid: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""DashboardPublic is deprecated: grafana.index/dashboardpublic.DashboardPublic has been deprecated in favor of grafana.oss/dashboardpublic.DashboardPublic""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardPublicArgs.__new__(DashboardPublicArgs)

            __props__.__dict__["access_token"] = access_token
            __props__.__dict__["annotations_enabled"] = annotations_enabled
            if dashboard_uid is None and not opts.urn:
                raise TypeError("Missing required property 'dashboard_uid'")
            __props__.__dict__["dashboard_uid"] = dashboard_uid
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["share"] = share
            __props__.__dict__["time_selection_enabled"] = time_selection_enabled
            __props__.__dict__["uid"] = uid
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/dashboardPublic:DashboardPublic")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(DashboardPublic, __self__).__init__(
            'grafana:index/dashboardPublic:DashboardPublic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_token: Optional[pulumi.Input[builtins.str]] = None,
            annotations_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            dashboard_uid: Optional[pulumi.Input[builtins.str]] = None,
            is_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            share: Optional[pulumi.Input[builtins.str]] = None,
            time_selection_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            uid: Optional[pulumi.Input[builtins.str]] = None) -> 'DashboardPublic':
        """
        Get an existing DashboardPublic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_token: A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        :param pulumi.Input[builtins.bool] annotations_enabled: Set to `true` to show annotations. The default value is `false`.
        :param pulumi.Input[builtins.str] dashboard_uid: The unique identifier of the original dashboard.
        :param pulumi.Input[builtins.bool] is_enabled: Set to `true` to enable the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] share: Set the share mode. The default value is `public`.
        :param pulumi.Input[builtins.bool] time_selection_enabled: Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        :param pulumi.Input[builtins.str] uid: The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardPublicState.__new__(_DashboardPublicState)

        __props__.__dict__["access_token"] = access_token
        __props__.__dict__["annotations_enabled"] = annotations_enabled
        __props__.__dict__["dashboard_uid"] = dashboard_uid
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["share"] = share
        __props__.__dict__["time_selection_enabled"] = time_selection_enabled
        __props__.__dict__["uid"] = uid
        return DashboardPublic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[builtins.str]:
        """
        A public unique identifier of a public dashboard. This is used to construct its URL. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "access_token")

    @property
    @pulumi.getter(name="annotationsEnabled")
    def annotations_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to `true` to show annotations. The default value is `false`.
        """
        return pulumi.get(self, "annotations_enabled")

    @property
    @pulumi.getter(name="dashboardUid")
    def dashboard_uid(self) -> pulumi.Output[builtins.str]:
        """
        The unique identifier of the original dashboard.
        """
        return pulumi.get(self, "dashboard_uid")

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to `true` to enable the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def share(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Set the share mode. The default value is `public`.
        """
        return pulumi.get(self, "share")

    @property
    @pulumi.getter(name="timeSelectionEnabled")
    def time_selection_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to `true` to enable the time picker in the public dashboard. The default value is `false`.
        """
        return pulumi.get(self, "time_selection_enabled")

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Output[builtins.str]:
        """
        The unique identifier of a public dashboard. It's automatically generated if not provided when creating a public dashboard.
        """
        return pulumi.get(self, "uid")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'HolidayCustomPeriod',
    'OutlierDetectorAlgorithm',
    'OutlierDetectorAlgorithmConfig',
]

@pulumi.output_type
class HolidayCustomPeriod(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "endTime":
            suggest = "end_time"
        elif key == "startTime":
            suggest = "start_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in HolidayCustomPeriod. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        HolidayCustomPeriod.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        HolidayCustomPeriod.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 end_time: builtins.str,
                 start_time: builtins.str,
                 name: Optional[builtins.str] = None):
        """
        :param builtins.str name: The name of the custom period.
        """
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "start_time", start_time)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> builtins.str:
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> builtins.str:
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The name of the custom period.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class OutlierDetectorAlgorithm(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 sensitivity: builtins.float,
                 config: Optional['outputs.OutlierDetectorAlgorithmConfig'] = None):
        """
        :param builtins.str name: The name of the algorithm to use ('mad' or 'dbscan').
        :param builtins.float sensitivity: Specify the sensitivity of the detector (in range [0,1]).
        :param 'OutlierDetectorAlgorithmConfigArgs' config: For DBSCAN only, specify the configuration map
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "sensitivity", sensitivity)
        if config is not None:
            pulumi.set(__self__, "config", config)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the algorithm to use ('mad' or 'dbscan').
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sensitivity(self) -> builtins.float:
        """
        Specify the sensitivity of the detector (in range [0,1]).
        """
        return pulumi.get(self, "sensitivity")

    @property
    @pulumi.getter
    def config(self) -> Optional['outputs.OutlierDetectorAlgorithmConfig']:
        """
        For DBSCAN only, specify the configuration map
        """
        return pulumi.get(self, "config")


@pulumi.output_type
class OutlierDetectorAlgorithmConfig(dict):
    def __init__(__self__, *,
                 epsilon: builtins.float):
        """
        :param builtins.float epsilon: Specify the epsilon parameter (positive float)
        """
        pulumi.set(__self__, "epsilon", epsilon)

    @property
    @pulumi.getter
    def epsilon(self) -> builtins.float:
        """
        Specify the epsilon parameter (positive float)
        """
        return pulumi.get(self, "epsilon")


